;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "racket-mode" "20260626.1429"
  "Racket editing, REPL, and more."
  '((emacs  "25.1")
    (compat "30.0.2.0"))
  :url "https://www.racket-mode.com/"
  :commit "97d9b8b7d73a02777c0f70ce6d145a99a99b37cb"
  :revdesc "97d9b8b7d73a"
  :authors '(("Greg Hendershott" . "racket-mode-author@greghendershott.com")))
